/* links_icon.c
 * Links Icon
 * (c) 2002 Karel 'Clock' Kulhavy
 * This file is a part of the Links program, released under GPL.
 */

#include "cfg.h"
#ifdef G
#include "links.h"

unsigned char *links_icon=
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0\2\0\0\2\0\0\2\0\0\2\0\0\2\0\0"
  "\2\0\0\2\0\0\2\0\0\2\0\0\2\0\0\2\0\0\2\0\0\2\0\0\2\0\0\2\0\0\2\0\0\0\0\0"
  "\0\0\0\0\2\0\0\2\0\0\2\0\0\2\0\0\2\0\0\2\0\0\2\0\0\2\0\0\2\0\0\2\0\0\2\0"
  "\0\2\0\0\2\0\0\2\0\0\2\0\0\2\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\262\0\0\326\0\0\326\0\0\326\0\0\326"
  "\0\0\326\0\0\326\0\0\326\0\0\326\0\0\326\0\0\326\0\0\326\0\0\326\0\0\326"
  "\0\0\326\0\0\326\0\0\315\0\0\33\0\0\0\33\0\0\316\0\0\327\0\0\327\0\0\327"
  "\0\0\327\0\0\327\0\0\327\0\0\327\0\0\327\0\0\327\0\0\327\0\0\327\0\0\327"
  "\0\0\327\0\0\327\0\0\327\0\0\262\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0\312\0\0\356\0\0\356\0\0\356\0\0\356\0"
  "\0\356\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356\0"
  "\0\356\0\0\356\0\0\346\0\0!\0\0\0!\0\0\354\0\0\374\0\0\374\0\0\374\0\0\374"
  "\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374"
  "\0\0\374\0\0\374\0\0\316\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\1\0\0\312\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356\0"
  "\0\356\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356\0"
  "\0\356\0\0\346\0\0!\0\0\0!\0\0\354\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374"
  "\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374"
  "\0\0\374\0\0\316\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\1\0\0\313\0\0\356\0\0\356\0\0\355\0\0\355\0\0\355\0\0\355\0"
  "\0\355\0\0\355\0\0\355\0\0\355\0\0\355\0\0\355\0\0\355\0\0\355\0\0\355\0"
  "\0\345\0\0\40\0\0\0\40\0\0\353\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0"
  "\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0"
  "\0\374\0\0\316\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\1\0\0\312\0\0\356\0\0\346\0\0\235\0\0b\0\0c\0\0c\0\0c\0\0c\0\0"
  "c\0\0c\0\0c\0\0c\0\0c\0\0c\0\0c\0\0[\0\0\10\0\0\0\16\0\0\335\0\0\374\0\0"
  "\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0"
  "\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\316\0\0\1\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0\312\0\0\356\0\0\343\0\0T\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\5\0\0\324\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374"
  "\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374"
  "\0\0\316\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\1\0\0\313\0\0\356\0\0\353\0\0\335\0\0\311\0\0\305\0\0\274\0\0\223\0"
  "\0'\0\0\0\0\0\0\0\0\0\0\0\0\0\0\13\0\0z\0\0\265\0\0\274\0\0\27\0\0\0\34\0"
  "\0\350\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0"
  "\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\316\0\0\1\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0\312\0\0"
  "\356\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356\0\0\351\0\0\215\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0A\0\0\342\0\0\356\0\0\346\0\0!\0\0\0!\0\0\354\0\0\374\0\0"
  "\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0"
  "\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\316\0\0\1\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0\312\0\0\356\0\0\356\0\0\356"
  "\0\0\356\0\0\356\0\0\356\0\0\352\0\0\226\0\0\0\0\0\0\0\0\0\0\0\0\0\0E\0\0"
  "\344\0\0\356\0\0\346\0\0!\0\0\0!\0\0\354\0\0\374\0\0\374\0\0\374\0\0\374"
  "\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374"
  "\0\0\374\0\0\374\0\0\316\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\1\0\0\313\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356\0"
  "\0\356\0\0\352\0\0\227\0\0\0\0\0\0\0\0\0\0\0\0\0\0F\0\0\344\0\0\356\0\0\346"
  "\0\0!\0\0\0!\0\0\354\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0"
  "\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0"
  "\316\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\1\0\0\312\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356\0\0\352\0\0\226"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0E\0\0\344\0\0\356\0\0\346\0\0!\0\0\0\37\0\0\350"
  "\0\0\373\0\0\373\0\0\373\0\0\373\0\0\373\0\0\373\0\0\373\0\0\373\0\0\373"
  "\0\0\373\0\0\373\0\0\373\0\0\373\0\0\373\0\0\373\0\0\311\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0\312\0\0\356\0"
  "\0\356\0\0\356\0\0\356\0\0\356\0\0\356\0\0\352\0\0\226\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0E\0\0\344\0\0\356\0\0\346\0\0!\0\0\0!\0\0\354\0\0\374\0\0\374\0"
  "\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0"
  "\0\374\0\0\374\0\0\374\0\0\374\0\0\316\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0\313\0\0\356\0\0\356\0\0\356\0\0"
  "\356\0\0\356\0\0\356\0\0\352\0\0\227\0\0\0\0\0\0\0\0\0\0\0\0\0\0F\0\0\344"
  "\0\0\356\0\0\346\0\0!\0\0\0!\0\0\354\0\0\374\0\0\374\0\0\374\0\0\374\0\0"
  "\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0"
  "\374\0\0\374\0\0\316\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\1\0\0\312\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356"
  "\0\0\352\0\0\226\0\0\0\0\0\0\0\0\0\0\0\0\0\0E\0\0\344\0\0\356\0\0\346\0\0"
  "!\0\0\0!\0\0\354\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374"
  "\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\316"
  "\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0"
  "\0\312\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356\0\0\352\0\0\226\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0E\0\0\344\0\0\356\0\0\346\0\0!\0\0\0!\0\0\354\0"
  "\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0"
  "\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\374\0\0\316\0\0\1\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0\313\0\0\356\0\0"
  "\356\0\0\356\0\0\356\0\0\356\0\0\356\0\0\352\0\0\227\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0F\0\0\344\0\0\356\0\0\346\0\0!\0\0\0!\0\0\351\0\0\365\0\0\365\0\0"
  "\365\0\0\365\0\0\365\0\0\365\0\0\365\0\0\365\0\0\365\0\0\365\0\0\365\0\0"
  "\365\0\0\365\0\0\365\0\0\365\0\0\315\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\232\0\0\272\0\0\272\0\0\272\0\0\272"
  "\0\0\272\0\0\272\0\0\265\0\0m\0\0\0\0\0\0\0\0\0\0\0\0\0\0""0\0\0\257\0\0"
  "\272\0\0\262\0\0\27\0\0\0\30\0\0\275\0\0\305\0\0\305\0\0\305\0\0\305\0\0"
  "\305\0\0\305\0\0\305\0\0\305\0\0\305\0\0\305\0\0\305\0\0\305\0\0\305\0\0"
  "\305\0\0\305\0\0\243\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\37\0\0)\0\0)\0\0)\0\0)\0\0)\0\0)\0\0'\0\0\23\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\7\0\0%\0\0(\0\0&\0\0\3\0\0\0\13\13\13\16\16\16"
  "\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16"
  "\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\10\10\10\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0\307\0"
  "\0\353\0\0\353\0\0\353\0\0\353\0\0\353\0\0\353\0\0\346\0\0\223\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0C\0\0\341\0\0\353\0\0\343\0\0\40\13\13\13\335\334\334\356"
  "\355\356\356\355\356\356\355\356\356\355\356\356\355\356\356\355\356\356"
  "\355\356\356\355\356\356\355\356\356\355\356\356\355\356\356\355\356\356"
  "\355\356\356\355\356\355\355\355\254\254\254\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0\312\0\0\356\0\0\356\0\0"
  "\356\0\0\356\0\0\356\0\0\356\0\0\352\0\0\226\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "E\0\0\344\0\0\356\0\0\346\0\0!\16\16\16\356\356\355\376\376\376\376\376\376"
  "\376\376\376\376\376\376\376\376\376\376\376\376\376\376\376\376\376\376"
  "\376\376\376\376\376\376\376\376\376\376\376\376\376\376\376\376\376\376"
  "\376\376\376\274\274\274\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\1\0\0\313\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356"
  "\0\0\356\0\0\352\0\0\227\0\0\0\0\0\0\0\0\0\0\0\0\0\0F\0\0\344\0\0\356\0\0"
  "\346\0\0!\16\16\16\356\356\355\376\376\376\376\376\376\376\376\376\376\376"
  "\376\376\376\376\376\376\376\376\376\376\376\376\376\376\376\376\376\376"
  "\376\373\373\373\356\356\356\351\351\351\371\371\371\376\376\376\274\274"
  "\274\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\1\0\0\312\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356\0\0\352\0\0"
  "\226\0\0\0\0\0\0\0\0\0\0\0\0\0\0E\0\0\344\0\0\356\0\0\346\0\0!\16\16\16\356"
  "\356\355\376\376\376\376\376\376\376\376\376\376\376\376\376\376\376\376"
  "\376\376\376\376\376\376\376\376\376\376\376\376\376\376\362\362\362HHH("
  "((\355\355\355\376\376\376\274\274\274\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0\312\0\0\356\0\0\356\0\0\356\0"
  "\0\356\0\0\356\0\0\356\0\0\352\0\0\226\0\0\0\0\0\0\0\0\0\0\0\0\0\0E\0\0\344"
  "\0\0\356\0\0\346\0\0!\16\16\16\356\356\355\376\376\376\376\376\376\376\376"
  "\376\376\376\376\376\376\376\376\376\376\376\376\376\376\376\376\376\376"
  "\376\376\376\376\340\340\340\13\13\13\16\16\16\354\354\354\376\376\376\274"
  "\274\274\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\1\0\0\313\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356\0\0\352"
  "\0\0\227\0\0\0\0\0\0\0\0\0\0\0\0\0\0F\0\0\344\0\0\356\0\0\346\0\0!\16\16"
  "\16\356\356\355\376\376\376\376\376\376\376\376\376\376\376\376\376\376\376"
  "\376\376\376\376\376\376\376\376\376\376\376\376\373\373\373\234\234\234"
  "\0\0\0)))\362\362\362\376\376\376\274\274\274\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0\312\0\0\356\0\0\356\0\0"
  "\356\0\0\356\0\0\356\0\0\356\0\0\352\0\0\226\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "E\0\0\344\0\0\356\0\0\346\0\0!\16\16\16\356\356\355\376\376\376\376\376\376"
  "\376\376\376\376\376\376\376\376\376\376\376\376\376\376\376\376\376\376"
  "\376\376\376\360\360\360DDD\0\0\0lll\370\370\370\376\376\376\274\274\274"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1"
  "\0\0\312\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356\0\0\352\0\0\226"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0E\0\0\344\0\0\356\0\0\346\0\0!\16\16\16\356\356"
  "\355\376\376\376\376\376\376\376\376\376\376\376\376\376\376\376\376\376"
  "\376\376\376\376\376\376\376\373\373\373\276\276\276\4\4\4\0\0\0xxx\372\372"
  "\372\376\376\376\274\274\274\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0\313\0\0\356\0\0\356\0\0\356\0\0\356\0\0"
  "\356\0\0\356\0\0\352\0\0\227\0\0\0\0\0\0\0\0\0\0\0\0\0\0F\0\0\344\0\0\356"
  "\0\0\346\0\0!\16\16\16\356\356\355\376\376\376\376\376\376\376\376\376\376"
  "\376\376\376\376\376\376\376\376\376\376\376\375\375\375\351\351\351>>>\0"
  "\0\0\0\0\0zzz\374\374\374\376\376\376\274\274\274\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0\312\0\0\356\0\0\356"
  "\0\0\356\0\0\356\0\0\356\0\0\356\0\0\352\0\0\226\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0E\0\0\344\0\0\356\0\0\346\0\0!\16\16\16\356\356\355\376\376\376\376\376"
  "\376\376\376\376\376\376\376\376\376\376\376\376\376\373\373\373\350\350"
  "\350ggg\0\0\0\0\0\0\0\0\0|||\375\375\375\376\376\376\274\274\274\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0\312"
  "\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356\0\0\355\0\0\347\0\0\203\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0""7\0\0\335\0\0\354\0\0\346\0\0!\16\16\16\355\355\355"
  "\376\376\376\376\376\376\375\375\375\374\374\374\367\367\367\352\352\352"
  "\255\255\255;;;\0\0\0\0\0\0\0\0\0\0\0\0\217\217\217\375\375\375\376\376\376"
  "\274\274\274\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\1\0\0\313\0\0\356\0\0\351\0\0\334\0\0\317\0\0\305\0\0\224\0\0"
  ">\0\0\17\0\0\0\0\0\0\0\0\0\0\0\0\0\0\3\0\0,\0\0h\0\0\264\0\0\26\11\11\11"
  "\304\304\304\323\323\323\306\306\306\215\215\215yyy[[[\31\31\31\1\1\1\0\0"
  "\0\0\0\0\0\0\0\0\0\0\5\5\5\326\326\326\376\376\376\376\376\376\274\274\274"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1"
  "\0\0\312\0\0\356\0\0\343\0\0]\0\0\4\0\0\2\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\1\1\1\1\1\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\13\13\13\343\343\343\376\376"
  "\376\376\376\376\274\274\274\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0\0\312\0\0\356\0\0\350\0\0\257\0\0x\0\0y\0"
  "\0y\0\0y\0\0y\0\0y\0\0y\0\0y\0\0y\0\0y\0\0y\0\0y\0\0r\0\0\14\4\4\4eeeppp"
  "pppppppppppppppppppppppppppnnn\213\213\213\362\362\362\376\376\376\376\376"
  "\376\274\274\274\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\1\0\0\313\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356"
  "\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356"
  "\0\0\345\0\0!\16\16\16\354\354\354\375\375\375\375\375\375\375\375\375\375"
  "\375\375\375\375\375\375\375\375\375\375\375\375\375\375\375\375\375\375"
  "\375\375\375\375\375\375\375\375\376\376\376\376\376\376\376\376\376\274"
  "\274\274\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\1\0\0\312\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356"
  "\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356\0\0\356\0\0\346"
  "\0\0!\16\16\16\356\356\355\376\376\376\376\376\376\376\376\376\376\376\376"
  "\376\376\376\376\376\376\376\376\376\376\376\376\376\376\376\376\376\376"
  "\376\376\376\376\376\376\376\376\376\376\376\376\376\376\376\274\274\274"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0h\0\0\177\0\0\177\0\0\177\0\0\177\0\0\177\0\0\177\0\0\177\0\0\177\0\0"
  "\177\0\0\177\0\0\177\0\0\177\0\0\177\0\0\177\0\0\177\0\0y\0\0\16\10\10\10"
  "\254\254\254\274\274\274\274\274\274\274\274\274\274\274\274\274\274\274"
  "\274\274\274\274\274\274\274\274\274\274\274\274\274\274\274\274\274\274"
  "\274\274\274\274\274\274\274\274\274\274\274\274\205\205\205\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0";
#endif /* #ifdef G */

